@@ -26,12 +26,12 @@
 # NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-from uml2orm.umlparser.base import BadOperation
+from uml2orm.parser.base import BadOperation
 
 class Database(object):
     """Representation of a database."""
     
-    def __init__(self, name, tables=None):#, indexes=None):
+    def __init__(self, name, tables=None):
         self.name = name
         self.tables = tables
 
@@ -41,7 +41,7 @@ class Table(object):
     
     def __init__(self, tid, name, table, columns=None, references=None, 
                  inherits=None, indexes=None, *args, **kwargs):
-        self.table = table # this is false when an UML class is inherited only
+        self.table = table # False when UML Class has stereotype == None
         self.tid = tid # table id
         self.name = name # table name
         self.columns = columns # a list of Column instances
@@ -81,32 +81,30 @@ def create_db_objs(dbname, tables_dict):
     for tid, table in tables_dict.items():
         new_table = table
         new_table.update({'tid': tid})
-        tcolumns = new_table.pop('columns')
+        columns = new_table.pop('columns')
         operations = new_table.pop('operations')
-        new_table['columns'] = [0] * len(tcolumns)
+        new_table['columns'] = [0] * len(columns)
 
         # create Columns and Index objects for current table
-        for column, data in tcolumns.items():
-            dtype, defval, index = data
+        for col, data in columns.iteritems():
+            dtype, defval, index = data # data type, default value, column index
             
-            if column not in operations:
-                new_table['columns'][index] = Column(column, dtype, 
-                                                     defval, None)
+            if col not in operations:
+                new_table['columns'][index] = Column(col, dtype, defval, None)
                 continue
             
-            opers = operations.pop(column)
+            opers = operations.pop(col)
             if len(opers) == 1 and opers[0][0] == 'index':
-                new_table['indexes'].append(column)
-                new_table['columns'][index] = Column(column, dtype, 
-                                                     defval, None)
+                new_table['indexes'].append(col)
+                new_table['columns'][index] = Column(col, dtype, defval, None)
                 continue
                 
             for op_name, op_type in opers:
                 if op_name == "index":
-                    new_table['indexes'].append(column)
+                    new_table['indexes'].append(col)
                     continue
                 
-                new_table['columns'][index] = Column(column, dtype, defval,
+                new_table['columns'][index] = Column(col, dtype, defval,
                                                      (op_name, op_type))
 
         if operations:
@@ -119,4 +117,4 @@ def create_db_objs(dbname, tables_dict):
 
         tables[tid] = Table(**new_table)
     
-    return Database(dbname, tables)
\ No newline at end of file
+    return Database(dbname, tables)
